@@ -240,9 +240,16 @@ class Config(AttrDict):
 
                 for k, v in zip(values[::2], values[1::2]):
                     try:
-                        getattr(namespace, self.dest)[k] = ast.literal_eval(v)
-                    except ValueError:
-                        getattr(namespace, self.dest)[k] = v
+                        v = ast.literal_eval(v)
+                    except (
+                        ValueError,
+                        TypeError,
+                        SyntaxError,
+                        MemoryError,
+                        RecursionError,
+                    ):
+                        pass
+                    getattr(namespace, self.dest)[k] = v
 
         class ConfigUnsetAction(argparse.Action):
             def __call__(
@@ -315,9 +322,10 @@ class Config(AttrDict):
 
         for k, v in zip(kv[::2], kv[1::2]):
             try:
-                ans[k] = ast.literal_eval(v)
-            except ValueError:
-                ans[k] = v
+                v = ast.literal_eval(v)
+            except (ValueError, TypeError, SyntaxError, MemoryError, RecursionError):
+                pass
+            ans[k] = v
 
         return ans
 
@@ -369,8 +377,11 @@ class Config(AttrDict):
         for k, v in self.items():
             try:
                 self[k] = v.resolve_transforms()
-            except AttributeError:
-                pass
+            except AttributeError as err:
+                if "has no attribute 'resolve_transforms'" in str(err):
+                    pass
+                else:
+                    raise
 
         if Config.TRANSFORM_CFG_TOKEN not in self:
             return self
@@ -610,7 +621,10 @@ class Config(AttrDict):
         for bname, bcfg in base_cfgs.items():
             cfg = deepcopy(start_cfg)
             cfg.rupdate(bcfg)
-            cfg_transform_resolved = deepcopy(cfg).resolve_transforms()
+            try:
+                cfg_transform_resolved = deepcopy(cfg).resolve_transforms()
+            except Exception:
+                continue
             cdiff = cfg_transform_resolved.diff(self)
             struct_diff, old_diff, new_diff = cdiff.diff_count()
             next_iter_cfgs.append(
